/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#ifndef SUPPORT_H
#define SUPPORT_H

typedef enum {
    Idle,
    Compiling,
    Executing
} UfhStateType;

extern UfhStateType UfhState;

char*	emalloc();
void	execerror(char *f, ...);
void	yyerror();

extern char*	progname;
extern int	lineno;
extern char*	infile;
extern char*	LastPushedVar;

#endif
